@@ -33,8 +33,7 @@ import (
 var testRevertCommitTargetBranch = "release"
 
 func TestGetCommit(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/repository/commits/b0b3a907f41409829b307a28b82fdbd552ee5a27", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -46,7 +45,7 @@ func TestGetCommit(t *testing.T) {
 		t.Fatalf("Commits.GetCommit returned error: %v, response: %v", err, resp)
 	}
 
-	updatedAt := time.Date(2019, 11, 4, 15, 39, 03, 935000000, time.UTC)
+	updatedAt := time.Date(2019, 11, 4, 15, 39, 0o3, 935000000, time.UTC)
 	createdAt := time.Date(2019, 11, 4, 15, 38, 53, 154000000, time.UTC)
 	want := &Commit{
 		ID:             "6104942438c14ec7bd21c6cd5bd995272b3faff6",
@@ -59,7 +58,7 @@ func TestGetCommit(t *testing.T) {
 		Message:        "Sanitize for network graph",
 		ParentIDs:      []string{"ae1d9fb46aa2b07ee9836d49862ec4e2c46fbbba"},
 		Stats:          &CommitStats{Additions: 15, Deletions: 10, Total: 25},
-		Status:         BuildState(Running),
+		Status:         Ptr(Running),
 		LastPipeline: &PipelineInfo{
 			ID:        8,
 			Ref:       "master",
@@ -76,8 +75,7 @@ func TestGetCommit(t *testing.T) {
 }
 
 func TestGetCommitStatuses(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/repository/commits/b0b3a907f41409829b307a28b82fdbd552ee5a27/statuses", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -85,13 +83,12 @@ func TestGetCommitStatuses(t *testing.T) {
 	})
 
 	opt := &GetCommitStatusesOptions{
-		Ref:   String("master"),
-		Stage: String("test"),
-		Name:  String("ci/jenkins"),
-		All:   Bool(true),
+		Ref:   Ptr("master"),
+		Stage: Ptr("test"),
+		Name:  Ptr("ci/jenkins"),
+		All:   Ptr(true),
 	}
 	statuses, _, err := client.Commits.GetCommitStatuses("1", "b0b3a907f41409829b307a28b82fdbd552ee5a27", opt)
-
 	if err != nil {
 		t.Errorf("Commits.GetCommitStatuses returned error: %v", err)
 	}
@@ -103,8 +100,7 @@ func TestGetCommitStatuses(t *testing.T) {
 }
 
 func TestSetCommitStatus(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/statuses/b0b3a907f41409829b307a28b82fdbd552ee5a27", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -123,15 +119,14 @@ func TestSetCommitStatus(t *testing.T) {
 	cov := 99.9
 	opt := &SetCommitStatusOptions{
 		State:       Running,
-		Ref:         String("master"),
-		Name:        String("ci/jenkins"),
-		Context:     String(""),
-		TargetURL:   String("http://abc"),
-		Description: String("build"),
+		Ref:         Ptr("master"),
+		Name:        Ptr("ci/jenkins"),
+		Context:     Ptr(""),
+		TargetURL:   Ptr("http://abc"),
+		Description: Ptr("build"),
 		Coverage:    &cov,
 	}
 	status, _, err := client.Commits.SetCommitStatus("1", "b0b3a907f41409829b307a28b82fdbd552ee5a27", opt)
-
 	if err != nil {
 		t.Errorf("Commits.SetCommitStatus returned error: %v", err)
 	}
@@ -143,8 +138,7 @@ func TestSetCommitStatus(t *testing.T) {
 }
 
 func TestRevertCommit_NoOptions(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/repository/commits/b0b3a907f41409829b307a28b82fdbd552ee5a27/revert", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -156,7 +150,7 @@ func TestRevertCommit_NoOptions(t *testing.T) {
 		t.Fatalf("Commits.RevertCommit returned error: %v, response: %v", err, resp)
 	}
 
-	updatedAt := time.Date(2019, 11, 4, 15, 39, 03, 935000000, time.UTC)
+	updatedAt := time.Date(2019, 11, 4, 15, 39, 0o3, 935000000, time.UTC)
 	createdAt := time.Date(2019, 11, 4, 15, 38, 53, 154000000, time.UTC)
 	want := &Commit{
 		ID:             "6104942438c14ec7bd21c6cd5bd995272b3faff6",
@@ -169,7 +163,7 @@ func TestRevertCommit_NoOptions(t *testing.T) {
 		Message:        "Sanitize for network graph",
 		ParentIDs:      []string{"ae1d9fb46aa2b07ee9836d49862ec4e2c46fbbba"},
 		Stats:          &CommitStats{Additions: 15, Deletions: 10, Total: 25},
-		Status:         BuildState(Running),
+		Status:         Ptr(Running),
 		LastPipeline: &PipelineInfo{
 			ID:        8,
 			Ref:       "master",
@@ -186,8 +180,7 @@ func TestRevertCommit_NoOptions(t *testing.T) {
 }
 
 func TestRevertCommit_WithOptions(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/repository/commits/b0b3a907f41409829b307a28b82fdbd552ee5a27/revert", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -202,7 +195,7 @@ func TestRevertCommit_WithOptions(t *testing.T) {
 		t.Fatalf("Commits.RevertCommit returned error: %v, response: %v", err, resp)
 	}
 
-	updatedAt := time.Date(2019, 11, 4, 15, 39, 03, 935000000, time.UTC)
+	updatedAt := time.Date(2019, 11, 4, 15, 39, 0o3, 935000000, time.UTC)
 	createdAt := time.Date(2019, 11, 4, 15, 38, 53, 154000000, time.UTC)
 	want := &Commit{
 		ID:             "6104942438c14ec7bd21c6cd5bd995272b3faff6",
@@ -215,7 +208,7 @@ func TestRevertCommit_WithOptions(t *testing.T) {
 		Message:        "Sanitize for network graph",
 		ParentIDs:      []string{"ae1d9fb46aa2b07ee9836d49862ec4e2c46fbbba"},
 		Stats:          &CommitStats{Additions: 15, Deletions: 10, Total: 25},
-		Status:         BuildState(Running),
+		Status:         Ptr(Running),
 		LastPipeline: &PipelineInfo{
 			ID:        8,
 			Ref:       "master",
@@ -232,15 +225,14 @@ func TestRevertCommit_WithOptions(t *testing.T) {
 }
 
 func TestGetGPGSignature(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/repository/commits/b0b3a907f41409829b307a28b82fdbd552ee5a27/signature", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
 		mustWriteHTTPResponse(t, w, "testdata/get_signature.json")
 	})
 
-	sig, resp, err := client.Commits.GetGPGSiganature("1", "b0b3a907f41409829b307a28b82fdbd552ee5a27", nil)
+	sig, resp, err := client.Commits.GetGPGSignature("1", "b0b3a907f41409829b307a28b82fdbd552ee5a27", nil)
 	if err != nil {
 		t.Fatalf("Commits.GetGPGSignature returned error: %v, response: %v", err, resp)
 	}
@@ -258,8 +250,7 @@ func TestGetGPGSignature(t *testing.T) {
 }
 
 func TestCommitsService_ListCommits(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/repository/commits", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -298,7 +289,7 @@ func TestCommitsService_ListCommits(t *testing.T) {
 		`)
 	})
 
-	updatedAt := time.Date(2019, 11, 4, 15, 39, 03, 935000000, time.UTC)
+	updatedAt := time.Date(2019, 11, 4, 15, 39, 0o3, 935000000, time.UTC)
 	createdAt := time.Date(2019, 11, 4, 15, 38, 53, 154000000, time.UTC)
 	want := []*Commit{{
 		ID:             "6104942438c14ec7bd21c6cd5bd995272b3faff6",
@@ -311,7 +302,7 @@ func TestCommitsService_ListCommits(t *testing.T) {
 		Message:        "Sanitize for network graph",
 		ParentIDs:      []string{"ae1d9fb46aa2b07ee9836d49862ec4e2c46fbbba"},
 		Stats:          &CommitStats{Additions: 15, Deletions: 10, Total: 25},
-		Status:         BuildState(Running),
+		Status:         Ptr(Running),
 		LastPipeline: &PipelineInfo{
 			ID:        8,
 			Ref:       "master",
@@ -346,8 +337,7 @@ func TestCommitsService_ListCommits(t *testing.T) {
 }
 
 func TestCommitsService_GetCommitRefs(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/repository/commits/5937ac0a7beb003549fc5fd26fc247adbce4a52e/refs", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -402,8 +392,7 @@ func TestCommitsService_GetCommitRefs(t *testing.T) {
 }
 
 func TestCommitsService_CreateCommit(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/repository/commits", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -440,7 +429,7 @@ func TestCommitsService_CreateCommit(t *testing.T) {
 		`)
 	})
 
-	updatedAt := time.Date(2019, 11, 4, 15, 39, 03, 935000000, time.UTC)
+	updatedAt := time.Date(2019, 11, 4, 15, 39, 0o3, 935000000, time.UTC)
 	createdAt := time.Date(2019, 11, 4, 15, 38, 53, 154000000, time.UTC)
 	want := &Commit{
 		ID:             "6104942438c14ec7bd21c6cd5bd995272b3faff6",
@@ -453,7 +442,7 @@ func TestCommitsService_CreateCommit(t *testing.T) {
 		Message:        "Sanitize for network graph",
 		ParentIDs:      []string{"ae1d9fb46aa2b07ee9836d49862ec4e2c46fbbba"},
 		Stats:          &CommitStats{Additions: 15, Deletions: 10, Total: 25},
-		Status:         BuildState(Running),
+		Status:         Ptr(Running),
 		LastPipeline: &PipelineInfo{
 			ID:        8,
 			Ref:       "master",
@@ -488,8 +477,7 @@ func TestCommitsService_CreateCommit(t *testing.T) {
 }
 
 func TestCommitsService_GetCommitDiff(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/repository/commits/master/diff", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -538,8 +526,7 @@ func TestCommitsService_GetCommitDiff(t *testing.T) {
 }
 
 func TestCommitsService_GetCommitComments(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/repository/commits/master/comments", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -592,8 +579,7 @@ func TestCommitsService_GetCommitComments(t *testing.T) {
 }
 
 func TestCommitsService_PostCommitComment(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/repository/commits/master/comments", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -644,8 +630,7 @@ func TestCommitsService_PostCommitComment(t *testing.T) {
 }
 
 func TestCommitsService_ListMergeRequestsByCommit(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/repository/commits/master/merge_requests", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -718,7 +703,7 @@ func TestCommitsService_ListMergeRequestsByCommit(t *testing.T) {
 				  "web_url": "https://gitlab.example.com/my-group/my-project/milestones/1"
 				},
 				"merge_when_pipeline_succeeds": true,
-				"merge_status": "can_be_merged",
+				"detailed_merge_status": "mergeable",
 				"sha": "8888888888888888888888888888888888888888",
 				"merge_commit_sha": null,
 				"squash_commit_sha": null,
@@ -795,9 +780,10 @@ func TestCommitsService_ListMergeRequestsByCommit(t *testing.T) {
 			Title:       "v2.0",
 			Description: "Assumenda aut placeat expedita exercitationem labore sunt enim earum.",
 			State:       "closed",
-			WebURL:      "https://gitlab.example.com/my-group/my-project/milestones/1"},
+			WebURL:      "https://gitlab.example.com/my-group/my-project/milestones/1",
+		},
 		MergeWhenPipelineSucceeds: true,
-		MergeStatus:               "can_be_merged",
+		DetailedMergeStatus:       "mergeable",
 		MergeError:                "",
 		MergedBy: &BasicUser{
 			ID:        87854,
@@ -805,7 +791,8 @@ func TestCommitsService_ListMergeRequestsByCommit(t *testing.T) {
 			Name:      "Douwe Maan",
 			State:     "active",
 			AvatarURL: "https://gitlab.example.com/uploads/-/system/user/avatar/87854/avatar.png",
-			WebURL:    "https://gitlab.com/DouweM"},
+			WebURL:    "https://gitlab.com/DouweM",
+		},
 		Subscribed:               false,
 		SHA:                      "8888888888888888888888888888888888888888",
 		MergeCommitSHA:           "",
@@ -859,8 +846,7 @@ func TestCommitsService_ListMergeRequestsByCommit(t *testing.T) {
 }
 
 func TestCommitsService_CherryPickCommit(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/repository/commits/master/cherry_pick", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -897,7 +883,7 @@ func TestCommitsService_CherryPickCommit(t *testing.T) {
 		`)
 	})
 
-	updatedAt := time.Date(2019, 11, 4, 15, 39, 03, 935000000, time.UTC)
+	updatedAt := time.Date(2019, 11, 4, 15, 39, 0o3, 935000000, time.UTC)
 	createdAt := time.Date(2019, 11, 4, 15, 38, 53, 154000000, time.UTC)
 	want := &Commit{
 		ID:             "6104942438c14ec7bd21c6cd5bd995272b3faff6",
@@ -910,7 +896,7 @@ func TestCommitsService_CherryPickCommit(t *testing.T) {
 		Message:        "Sanitize for network graph",
 		ParentIDs:      []string{"ae1d9fb46aa2b07ee9836d49862ec4e2c46fbbba"},
 		Stats:          &CommitStats{Additions: 15, Deletions: 10, Total: 25},
-		Status:         BuildState(Running),
+		Status:         Ptr(Running),
 		LastPipeline: &PipelineInfo{
 			ID:        8,
 			Ref:       "master",
