@@ -37,6 +37,19 @@ func TestWebhookEventType(t *testing.T) {
 	}
 }
 
+func TestWebhookEventToken(t *testing.T) {
+	req, err := http.NewRequest(http.MethodGet, "https://gitlab.com", nil)
+	if err != nil {
+		t.Errorf("Error creating HTTP request: %s", err)
+	}
+	req.Header.Set("X-Gitlab-Token", "798d3dd3-67f5-41df-ad19-7882cc6263bf")
+
+	actualToken := HookEventToken(req)
+	if actualToken != "798d3dd3-67f5-41df-ad19-7882cc6263bf" {
+		t.Errorf("WebhookEventToken is %q, want %q", actualToken, "798d3dd3-67f5-41df-ad19-7882cc6263bf")
+	}
+}
+
 func TestParseBuildHook(t *testing.T) {
 	raw := loadFixture("testdata/webhooks/build.json")
 
@@ -101,7 +114,7 @@ func TestParseCommitCommentHook(t *testing.T) {
 	}
 }
 
-func TestParseFeatureFLagHook(t *testing.T) {
+func TestParseFeatureFlagHook(t *testing.T) {
 	raw := loadFixture("testdata/webhooks/feature_flag.json")
 
 	parsedEvent, err := ParseWebhook("Feature Flag Hook", raw)
@@ -147,6 +160,26 @@ func TestParseFeatureFLagHook(t *testing.T) {
 	}
 }
 
+func TestParseGroupResourceAccessTokenHook(t *testing.T) {
+	raw := loadFixture("testdata/webhooks/resource_access_token_group.json")
+
+	parsedEvent, err := ParseWebhook("Resource Access Token Hook", raw)
+	if err != nil {
+		t.Errorf("Error parsing group resource access token hook: %s", err)
+	}
+
+	event, ok := parsedEvent.(*GroupResourceAccessTokenEvent)
+	if !ok {
+		t.Errorf("Expected GroupResourceAccessTokenEvent, but parsing produced %T", parsedEvent)
+	}
+
+	expectedEventName := "expiring_access_token"
+
+	if event.EventName != expectedEventName {
+		t.Errorf("EventName is %v, want %v", event.EventName, expectedEventName)
+	}
+}
+
 func TestParseHookWebHook(t *testing.T) {
 	parsedEvent1, err := ParseHook("Merge Request Hook", loadFixture("testdata/webhooks/merge_request.json"))
 	if err != nil {
@@ -351,6 +384,26 @@ func TestParsePipelineHook(t *testing.T) {
 	}
 }
 
+func TestParseProjectResourceAccessTokenHook(t *testing.T) {
+	raw := loadFixture("testdata/webhooks/resource_access_token_project.json")
+
+	parsedEvent, err := ParseWebhook("Resource Access Token Hook", raw)
+	if err != nil {
+		t.Errorf("Error parsing project resource access token hook: %s", err)
+	}
+
+	event, ok := parsedEvent.(*ProjectResourceAccessTokenEvent)
+	if !ok {
+		t.Errorf("Expected ProjectResourceAccessTokenEvent, but parsing produced %T", parsedEvent)
+	}
+
+	expectedEventName := "expiring_access_token"
+
+	if event.EventName != expectedEventName {
+		t.Errorf("EventName is %v, want %v", event.EventName, expectedEventName)
+	}
+}
+
 func TestParsePushHook(t *testing.T) {
 	raw := loadFixture("testdata/webhooks/push.json")
 
