@@ -20,6 +20,7 @@ import (
 	"bytes"
 	"encoding/json"
 	"fmt"
+	"io"
 	"net/http"
 	"os"
 	"reflect"
@@ -39,13 +40,13 @@ func TestListProjects(t *testing.T) {
 	})
 
 	opt := &ListProjectsOptions{
-		ListOptions: ListOptions{2, 3},
-		Archived:    Bool(true),
-		OrderBy:     String("name"),
-		Sort:        String("asc"),
-		Search:      String("query"),
-		Simple:      Bool(true),
-		Visibility:  Visibility(PublicVisibility),
+		ListOptions: ListOptions{Page: 2, PerPage: 3},
+		Archived:    Ptr(true),
+		OrderBy:     Ptr("name"),
+		Sort:        Ptr("asc"),
+		Search:      Ptr("query"),
+		Simple:      Ptr(true),
+		Visibility:  Ptr(PublicVisibility),
 	}
 
 	projects, _, err := client.Projects.ListProjects(opt)
@@ -68,13 +69,13 @@ func TestListUserProjects(t *testing.T) {
 	})
 
 	opt := &ListProjectsOptions{
-		ListOptions: ListOptions{2, 3},
-		Archived:    Bool(true),
-		OrderBy:     String("name"),
-		Sort:        String("asc"),
-		Search:      String("query"),
-		Simple:      Bool(true),
-		Visibility:  Visibility(PublicVisibility),
+		ListOptions: ListOptions{Page: 2, PerPage: 3},
+		Archived:    Ptr(true),
+		OrderBy:     Ptr("name"),
+		Sort:        Ptr("asc"),
+		Search:      Ptr("query"),
+		Simple:      Ptr(true),
+		Visibility:  Ptr(PublicVisibility),
 	}
 
 	projects, _, err := client.Projects.ListUserProjects(1, opt)
@@ -88,6 +89,35 @@ func TestListUserProjects(t *testing.T) {
 	}
 }
 
+func TestListUserContributedProjects(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/users/1/contributed_projects", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		fmt.Fprint(w, `[{"id":1},{"id":2}]`)
+	})
+
+	opt := &ListProjectsOptions{
+		ListOptions: ListOptions{Page: 2, PerPage: 3},
+		Archived:    Bool(true),
+		OrderBy:     String("name"),
+		Sort:        String("asc"),
+		Search:      String("query"),
+		Simple:      Bool(true),
+		Visibility:  Visibility(PublicVisibility),
+	}
+
+	projects, _, err := client.Projects.ListUserContributedProjects(1, opt)
+	if err != nil {
+		t.Errorf("Projects.ListUserContributedProjects returned error: %v", err)
+	}
+
+	want := []*Project{{ID: 1}, {ID: 2}}
+	if !reflect.DeepEqual(want, projects) {
+		t.Errorf("Projects.ListUserContributedProjects returned %+v, want %+v", projects, want)
+	}
+}
+
 func TestListUserStarredProjects(t *testing.T) {
 	mux, client := setup(t)
 
@@ -97,13 +127,13 @@ func TestListUserStarredProjects(t *testing.T) {
 	})
 
 	opt := &ListProjectsOptions{
-		ListOptions: ListOptions{2, 3},
-		Archived:    Bool(true),
-		OrderBy:     String("name"),
-		Sort:        String("asc"),
-		Search:      String("query"),
-		Simple:      Bool(true),
-		Visibility:  Visibility(PublicVisibility),
+		ListOptions: ListOptions{Page: 2, PerPage: 3},
+		Archived:    Ptr(true),
+		OrderBy:     Ptr("name"),
+		Sort:        Ptr("asc"),
+		Search:      Ptr("query"),
+		Simple:      Ptr(true),
+		Visibility:  Ptr(PublicVisibility),
 	}
 
 	projects, _, err := client.Projects.ListUserStarredProjects(1, opt)
@@ -127,8 +157,8 @@ func TestListProjectsUsersByID(t *testing.T) {
 	})
 
 	opt := &ListProjectUserOptions{
-		ListOptions: ListOptions{2, 3},
-		Search:      String("query"),
+		ListOptions: ListOptions{Page: 2, PerPage: 3},
+		Search:      Ptr("query"),
 	}
 
 	projects, _, err := client.Projects.ListProjectsUsers(1, opt)
@@ -152,8 +182,8 @@ func TestListProjectsUsersByName(t *testing.T) {
 	})
 
 	opt := &ListProjectUserOptions{
-		ListOptions: ListOptions{2, 3},
-		Search:      String("query"),
+		ListOptions: ListOptions{Page: 2, PerPage: 3},
+		Search:      Ptr("query"),
 	}
 
 	projects, _, err := client.Projects.ListProjectsUsers("namespace/name", opt)
@@ -177,8 +207,8 @@ func TestListProjectsGroupsByID(t *testing.T) {
 	})
 
 	opt := &ListProjectGroupOptions{
-		ListOptions: ListOptions{2, 3},
-		Search:      String("query"),
+		ListOptions: ListOptions{Page: 2, PerPage: 3},
+		Search:      Ptr("query"),
 	}
 
 	groups, _, err := client.Projects.ListProjectsGroups(1, opt)
@@ -202,8 +232,8 @@ func TestListProjectsGroupsByName(t *testing.T) {
 	})
 
 	opt := &ListProjectGroupOptions{
-		ListOptions: ListOptions{2, 3},
-		Search:      String("query"),
+		ListOptions: ListOptions{Page: 2, PerPage: 3},
+		Search:      Ptr("query"),
 	}
 
 	groups, _, err := client.Projects.ListProjectsGroups("namespace/name", opt)
@@ -226,14 +256,14 @@ func TestListOwnedProjects(t *testing.T) {
 	})
 
 	opt := &ListProjectsOptions{
-		ListOptions: ListOptions{2, 3},
-		Archived:    Bool(true),
-		OrderBy:     String("name"),
-		Sort:        String("asc"),
-		Search:      String("query"),
-		Simple:      Bool(true),
-		Owned:       Bool(true),
-		Visibility:  Visibility(PublicVisibility),
+		ListOptions: ListOptions{Page: 2, PerPage: 3},
+		Archived:    Ptr(true),
+		OrderBy:     Ptr("name"),
+		Sort:        Ptr("asc"),
+		Search:      Ptr("query"),
+		Simple:      Ptr(true),
+		Owned:       Ptr(true),
+		Visibility:  Ptr(PublicVisibility),
 	}
 
 	projects, _, err := client.Projects.ListProjects(opt)
@@ -247,6 +277,53 @@ func TestListOwnedProjects(t *testing.T) {
 	}
 }
 
+func TestEditProject(t *testing.T) {
+	mux, client := setup(t)
+
+	var developerAccessLevel AccessControlValue = "developer"
+	opt := &EditProjectOptions{
+		CIRestrictPipelineCancellationRole: Ptr(developerAccessLevel),
+	}
+
+	// Store whether we've set the restrict value in our edit properly
+	restrictValueSet := false
+
+	mux.HandleFunc("/api/v4/projects/1", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodPut)
+
+		// Check that our request properly included ci_restrict_pipeline_cancellation_role
+		body, err := io.ReadAll(r.Body)
+		if err != nil {
+			t.Fatalf("Unable to read body properly. Error: %v", err)
+		}
+
+		// Set the value to check if our value is included
+		restrictValueSet = strings.Contains(string(body), "ci_restrict_pipeline_cancellation_role")
+
+		// Print the start of the mock example from https://docs.gitlab.com/ee/api/projects.html#edit-project
+		// including the attribute we edited
+		fmt.Fprint(w, `
+		{
+			"id": 1,
+			"description": "Lorem ipsum dolor sit amet, consectetur adipiscing elit.",
+			"description_html": "<p data-sourcepos=\"1:1-1:56\" dir=\"auto\">Lorem ipsum dolor sit amet, consectetur adipiscing elit.</p>",
+			"default_branch": "main",
+			"visibility": "private",
+			"ssh_url_to_repo": "git@example.com:diaspora/diaspora-project-site.git",
+			"http_url_to_repo": "http://example.com/diaspora/diaspora-project-site.git",
+			"web_url": "http://example.com/diaspora/diaspora-project-site",
+			"readme_url": "http://example.com/diaspora/diaspora-project-site/blob/main/README.md",
+			"ci_restrict_pipeline_cancellation_role": "developer"
+		}`)
+	})
+
+	project, resp, err := client.Projects.EditProject(1, opt)
+	assert.NoError(t, err)
+	assert.Equal(t, http.StatusOK, resp.StatusCode)
+	assert.Equal(t, true, restrictValueSet)
+	assert.Equal(t, developerAccessLevel, project.CIRestrictPipelineCancellationRole)
+}
+
 func TestListStarredProjects(t *testing.T) {
 	mux, client := setup(t)
 
@@ -256,14 +333,14 @@ func TestListStarredProjects(t *testing.T) {
 	})
 
 	opt := &ListProjectsOptions{
-		ListOptions: ListOptions{2, 3},
-		Archived:    Bool(true),
-		OrderBy:     String("name"),
-		Sort:        String("asc"),
-		Search:      String("query"),
-		Simple:      Bool(true),
-		Starred:     Bool(true),
-		Visibility:  Visibility(PublicVisibility),
+		ListOptions: ListOptions{Page: 2, PerPage: 3},
+		Archived:    Ptr(true),
+		OrderBy:     Ptr("name"),
+		Sort:        Ptr("asc"),
+		Search:      Ptr("query"),
+		Simple:      Ptr(true),
+		Starred:     Ptr(true),
+		Visibility:  Ptr(PublicVisibility),
 	}
 
 	projects, _, err := client.Projects.ListProjects(opt)
@@ -294,6 +371,9 @@ func TestGetProjectByID(t *testing.T) {
 			  "name_regex_keep": null,
 			  "next_run_at": "2020-01-07T21:42:58.658Z"
 			},
+			"ci_forward_deployment_enabled": true,
+			"ci_forward_deployment_rollback_allowed": true,
+			"ci_restrict_pipeline_cancellation_role": "developer",
 			"packages_enabled": false,
 			"build_coverage_regex": "Total.*([0-9]{1,3})%"
 		  }`)
@@ -307,8 +387,11 @@ func TestGetProjectByID(t *testing.T) {
 			Cadence:   "7d",
 			NextRunAt: &wantTimestamp,
 		},
-		PackagesEnabled:    false,
-		BuildCoverageRegex: `Total.*([0-9]{1,3})%`,
+		PackagesEnabled:                    false,
+		BuildCoverageRegex:                 `Total.*([0-9]{1,3})%`,
+		CIForwardDeploymentEnabled:         true,
+		CIForwardDeploymentRollbackAllowed: true,
+		CIRestrictPipelineCancellationRole: "developer",
 	}
 
 	project, _, err := client.Projects.GetProject(1, nil)
@@ -358,7 +441,8 @@ func TestGetProjectWithOptions(t *testing.T) {
 				"pipeline_artifacts_size": 0,
 				"packages_size": 238906167,
 				"snippets_size": 146800,
-				"uploads_size": 6523619
+				"uploads_size": 6523619,
+				"container_registry_size": 284453
 			}}`)
 	})
 	want := &Project{ID: 1, Statistics: &Statistics{
@@ -372,9 +456,10 @@ func TestGetProjectWithOptions(t *testing.T) {
 		PackagesSize:          238906167,
 		SnippetsSize:          146800,
 		UploadsSize:           6523619,
+		ContainerRegistrySize: 284453,
 	}}
 
-	project, _, err := client.Projects.GetProject(1, &GetProjectOptions{Statistics: Bool(true)})
+	project, _, err := client.Projects.GetProject(1, &GetProjectOptions{Statistics: Ptr(true)})
 	if err != nil {
 		t.Fatalf("Projects.GetProject returns an error: %v", err)
 	}
@@ -393,8 +478,8 @@ func TestCreateProject(t *testing.T) {
 	})
 
 	opt := &CreateProjectOptions{
-		Name:        String("n"),
-		MergeMethod: MergeMethod(RebaseMerge),
+		Name:        Ptr("n"),
+		MergeMethod: Ptr(RebaseMerge),
 	}
 
 	project, _, err := client.Projects.CreateProject(opt)
@@ -543,13 +628,13 @@ func TestListProjectForks(t *testing.T) {
 	})
 
 	opt := &ListProjectsOptions{}
-	opt.ListOptions = ListOptions{2, 3}
-	opt.Archived = Bool(true)
-	opt.OrderBy = String("name")
-	opt.Sort = String("asc")
-	opt.Search = String("query")
-	opt.Simple = Bool(true)
-	opt.Visibility = Visibility(PublicVisibility)
+	opt.ListOptions = ListOptions{Page: 2, PerPage: 3}
+	opt.Archived = Ptr(true)
+	opt.OrderBy = Ptr("name")
+	opt.Sort = Ptr("asc")
+	opt.Search = Ptr("query")
+	opt.Simple = Ptr(true)
+	opt.Visibility = Ptr(PublicVisibility)
 
 	projects, _, err := client.Projects.ListProjectForks("namespace/name", opt)
 	if err != nil {
@@ -562,6 +647,24 @@ func TestListProjectForks(t *testing.T) {
 	}
 }
 
+func TestDeleteProject(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodDelete)
+	})
+
+	opt := &DeleteProjectOptions{
+		FullPath:          Ptr("group/project"),
+		PermanentlyRemove: Ptr(true),
+	}
+
+	_, err := client.Projects.DeleteProject(1, opt)
+	if err != nil {
+		t.Errorf("Projects.DeleteProject returned error: %v", err)
+	}
+}
+
 func TestShareProjectWithGroup(t *testing.T) {
 	mux, client := setup(t)
 
@@ -570,8 +673,8 @@ func TestShareProjectWithGroup(t *testing.T) {
 	})
 
 	opt := &ShareWithGroupOptions{
-		GroupID:     Int(1),
-		GroupAccess: AccessLevel(AccessLevelValue(50)),
+		GroupID:     Ptr(1),
+		GroupAccess: Ptr(AccessLevelValue(50)),
 	}
 
 	_, err := client.Projects.ShareProjectWithGroup(1, opt)
@@ -650,7 +753,7 @@ func TestChangeApprovalConfiguration(t *testing.T) {
 	})
 
 	opt := &ChangeApprovalConfigurationOptions{
-		ApprovalsBeforeMerge: Int(3),
+		ApprovalsBeforeMerge: Ptr(3),
 	}
 
 	approvals, _, err := client.Projects.ChangeApprovalConfiguration(1, opt)
@@ -744,9 +847,9 @@ func TestForkProject(t *testing.T) {
 	})
 
 	project, _, err := client.Projects.ForkProject(1, &ForkProjectOptions{
-		NamespaceID: Int(namespaceID),
-		Name:        String(name),
-		Path:        String(path),
+		NamespaceID: Ptr(namespaceID),
+		Name:        Ptr(name),
+		Path:        Ptr(path),
 	})
 	if err != nil {
 		t.Errorf("Projects.ForkProject returned error: %v", err)
@@ -1190,10 +1293,11 @@ func TestCreateProjectApprovalRule(t *testing.T) {
 	})
 
 	opt := &CreateProjectLevelRuleOptions{
-		Name:              String("security"),
-		ApprovalsRequired: Int(3),
+		Name:              Ptr("security"),
+		ApprovalsRequired: Ptr(3),
 		UserIDs:           &[]int{5, 50},
 		GroupIDs:          &[]int{5},
+		ReportType:        String("code_coverage"),
 	}
 
 	rule, _, err := client.Projects.CreateProjectApprovalRule(1, opt)
@@ -1340,8 +1444,8 @@ func TestCreateProjectApprovalRuleEligibleApprovers(t *testing.T) {
 	})
 
 	opt := &CreateProjectLevelRuleOptions{
-		Name:              String("Any name"),
-		ApprovalsRequired: Int(1),
+		Name:              Ptr("Any name"),
+		ApprovalsRequired: Ptr(1),
 	}
 
 	rule, _, err := client.Projects.CreateProjectApprovalRule(1, opt)
@@ -1368,7 +1472,7 @@ func TestCreateProjectApprovalRuleEligibleApprovers(t *testing.T) {
 func TestProjectModelsOptionalMergeAttribute(t *testing.T) {
 	// Create a `CreateProjectOptions` struct, ensure that merge attribute doesn't serialize
 	jsonString, err := json.Marshal(&CreateProjectOptions{
-		Name: String("testProject"),
+		Name: Ptr("testProject"),
 	})
 	if err != nil {
 		t.Fatal("Failed to marshal object", err)
@@ -1377,10 +1481,390 @@ func TestProjectModelsOptionalMergeAttribute(t *testing.T) {
 
 	// Test the same thing but for `EditProjectOptions` struct
 	jsonString, err = json.Marshal(&EditProjectOptions{
-		Name: String("testProject"),
+		Name: Ptr("testProject"),
 	})
 	if err != nil {
 		t.Fatal("Failed to marshal object", err)
 	}
 	assert.False(t, strings.Contains(string(jsonString), "only_allow_merge_if_all_status_checks_passed"))
 }
+
+// Test that the "CustomWebhookTemplate" serializes properly
+func TestProjectAddWebhook_CustomTemplateStuff(t *testing.T) {
+	mux, client := setup(t)
+	customWebhookSet := false
+	authValueSet := false
+
+	mux.HandleFunc("/api/v4/projects/1/hooks",
+		func(w http.ResponseWriter, r *http.Request) {
+			testMethod(t, r, http.MethodPost)
+			w.WriteHeader(http.StatusCreated)
+
+			body, err := io.ReadAll(r.Body)
+			if err != nil {
+				t.Fatalf("Unable to read body properly. Error: %v", err)
+			}
+			customWebhookSet = strings.Contains(string(body), "custom_webhook_template")
+			authValueSet = strings.Contains(string(body), `"value":"stuff"`)
+
+			fmt.Fprint(w, `{
+				"custom_webhook_template": "testValue",
+				"custom_headers": [
+					{
+						"key": "Authorization"
+					},
+					{
+						"key": "Favorite-Pet"
+					}
+				]
+			}`)
+		},
+	)
+
+	hook, resp, err := client.Projects.AddProjectHook(1, &AddProjectHookOptions{
+		CustomWebhookTemplate: Ptr(`{"example":"{{object_kind}}"}`),
+		CustomHeaders: &[]*HookCustomHeader{
+			{
+				Key:   "Authorization",
+				Value: "stuff",
+			},
+			{
+				Key:   "Favorite-Pet",
+				Value: "Cats",
+			},
+		},
+	})
+
+	assert.NoError(t, err)
+	assert.Equal(t, http.StatusCreated, resp.StatusCode)
+	assert.Equal(t, true, customWebhookSet)
+	assert.Equal(t, true, authValueSet)
+	assert.Equal(t, "testValue", hook.CustomWebhookTemplate)
+	assert.Equal(t, 2, len(hook.CustomHeaders))
+}
+
+// Test that the "CustomWebhookTemplate" serializes properly when editing
+func TestProjectEditWebhook_CustomTemplateStuff(t *testing.T) {
+	mux, client := setup(t)
+	customWebhookSet := false
+	authValueSet := false
+
+	mux.HandleFunc("/api/v4/projects/1/hooks/1",
+		func(w http.ResponseWriter, r *http.Request) {
+			testMethod(t, r, http.MethodPut)
+			w.WriteHeader(http.StatusOK)
+
+			body, err := io.ReadAll(r.Body)
+			if err != nil {
+				t.Fatalf("Unable to read body properly. Error: %v", err)
+			}
+			customWebhookSet = strings.Contains(string(body), "custom_webhook_template")
+			authValueSet = strings.Contains(string(body), `"value":"stuff"`)
+
+			fmt.Fprint(w, `{
+				"custom_webhook_template": "testValue",
+				"custom_headers": [
+					{
+						"key": "Authorization"
+					},
+					{
+						"key": "Favorite-Pet"
+					}
+				]}`)
+		},
+	)
+
+	hook, resp, err := client.Projects.EditProjectHook(1, 1, &EditProjectHookOptions{
+		CustomWebhookTemplate: Ptr(`{"example":"{{object_kind}}"}`),
+		CustomHeaders: &[]*HookCustomHeader{
+			{
+				Key:   "Authorization",
+				Value: "stuff",
+			},
+			{
+				Key:   "Favorite-Pet",
+				Value: "Cats",
+			},
+		},
+	})
+
+	assert.NoError(t, err)
+	assert.Equal(t, http.StatusOK, resp.StatusCode)
+	assert.Equal(t, true, customWebhookSet)
+	assert.Equal(t, true, authValueSet)
+	assert.Equal(t, "testValue", hook.CustomWebhookTemplate)
+	assert.Equal(t, 2, len(hook.CustomHeaders))
+}
+
+func TestGetProjectPushRules(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/push_rule", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		fmt.Fprint(w, `{
+			"id": 1,
+			"commit_message_regex": "Fixes \\d+\\..*",
+			"commit_message_negative_regex": "ssh\\:\\/\\/",
+			"branch_name_regex": "(feat|fix)\\/*",
+			"deny_delete_tag": false,
+			"member_check": false,
+			"prevent_secrets": false,
+			"author_email_regex": "@company.com$",
+			"file_name_regex": "(jar|exe)$",
+			"max_file_size": 5,
+			"commit_committer_check": false,
+			"commit_committer_name_check": false,
+			"reject_unsigned_commits": false,
+			"reject_non_dco_commits": false
+		  }`)
+	})
+
+	rule, _, err := client.Projects.GetProjectPushRules(1)
+	if err != nil {
+		t.Errorf("Projects.GetProjectPushRules returned error: %v", err)
+	}
+
+	want := &ProjectPushRules{
+		ID:                         1,
+		CommitMessageRegex:         "Fixes \\d+\\..*",
+		CommitMessageNegativeRegex: "ssh\\:\\/\\/",
+		BranchNameRegex:            "(feat|fix)\\/*",
+		DenyDeleteTag:              false,
+		MemberCheck:                false,
+		PreventSecrets:             false,
+		AuthorEmailRegex:           "@company.com$",
+		FileNameRegex:              "(jar|exe)$",
+		MaxFileSize:                5,
+		CommitCommitterCheck:       false,
+		CommitCommitterNameCheck:   false,
+		RejectUnsignedCommits:      false,
+		RejectNonDCOCommits:        false,
+	}
+
+	if !reflect.DeepEqual(want, rule) {
+		t.Errorf("Projects.GetProjectPushRules returned %+v, want %+v", rule, want)
+	}
+}
+
+func TestAddProjectPushRules(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/push_rule", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodPost)
+		fmt.Fprint(w, `{
+			"id": 1,
+			"commit_message_regex": "Fixes \\d+\\..*",
+			"commit_message_negative_regex": "ssh\\:\\/\\/",
+			"branch_name_regex": "(feat|fix)\\/*",
+			"deny_delete_tag": false,
+			"member_check": false,
+			"prevent_secrets": false,
+			"author_email_regex": "@company.com$",
+			"file_name_regex": "(jar|exe)$",
+			"max_file_size": 5,
+			"commit_committer_check": false,
+			"commit_committer_name_check": false,
+			"reject_unsigned_commits": false,
+			"reject_non_dco_commits": false
+		  }`)
+	})
+
+	opt := &AddProjectPushRuleOptions{
+		CommitMessageRegex:         Ptr("Fixes \\d+\\..*"),
+		CommitMessageNegativeRegex: Ptr("ssh\\:\\/\\/"),
+		BranchNameRegex:            Ptr("(feat|fix)\\/*"),
+		DenyDeleteTag:              Ptr(false),
+		MemberCheck:                Ptr(false),
+		PreventSecrets:             Ptr(false),
+		AuthorEmailRegex:           Ptr("@company.com$"),
+		FileNameRegex:              Ptr("(jar|exe)$"),
+		MaxFileSize:                Ptr(5),
+		CommitCommitterCheck:       Ptr(false),
+		CommitCommitterNameCheck:   Ptr(false),
+		RejectUnsignedCommits:      Ptr(false),
+		RejectNonDCOCommits:        Ptr(false),
+	}
+
+	rule, _, err := client.Projects.AddProjectPushRule(1, opt)
+	if err != nil {
+		t.Errorf("Projects.AddProjectPushRule returned error: %v", err)
+	}
+
+	want := &ProjectPushRules{
+		ID:                         1,
+		CommitMessageRegex:         "Fixes \\d+\\..*",
+		CommitMessageNegativeRegex: "ssh\\:\\/\\/",
+		BranchNameRegex:            "(feat|fix)\\/*",
+		DenyDeleteTag:              false,
+		MemberCheck:                false,
+		PreventSecrets:             false,
+		AuthorEmailRegex:           "@company.com$",
+		FileNameRegex:              "(jar|exe)$",
+		MaxFileSize:                5,
+		CommitCommitterCheck:       false,
+		CommitCommitterNameCheck:   false,
+		RejectUnsignedCommits:      false,
+		RejectNonDCOCommits:        false,
+	}
+
+	if !reflect.DeepEqual(want, rule) {
+		t.Errorf("Projects.AddProjectPushRule returned %+v, want %+v", rule, want)
+	}
+}
+
+func TestEditProjectPushRules(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/push_rule", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodPut)
+		fmt.Fprint(w, `{
+			"id": 1,
+			"commit_message_regex": "Fixes \\d+\\..*",
+			"commit_message_negative_regex": "ssh\\:\\/\\/",
+			"branch_name_regex": "(feat|fix)\\/*",
+			"deny_delete_tag": false,
+			"member_check": false,
+			"prevent_secrets": false,
+			"author_email_regex": "@company.com$",
+			"file_name_regex": "(jar|exe)$",
+			"max_file_size": 5,
+			"commit_committer_check": false,
+			"commit_committer_name_check": false,
+			"reject_unsigned_commits": false,
+			"reject_non_dco_commits": false
+		  }`)
+	})
+
+	opt := &EditProjectPushRuleOptions{
+		CommitMessageRegex:         Ptr("Fixes \\d+\\..*"),
+		CommitMessageNegativeRegex: Ptr("ssh\\:\\/\\/"),
+		BranchNameRegex:            Ptr("(feat|fix)\\/*"),
+		DenyDeleteTag:              Ptr(false),
+		MemberCheck:                Ptr(false),
+		PreventSecrets:             Ptr(false),
+		AuthorEmailRegex:           Ptr("@company.com$"),
+		FileNameRegex:              Ptr("(jar|exe)$"),
+		MaxFileSize:                Ptr(5),
+		CommitCommitterCheck:       Ptr(false),
+		CommitCommitterNameCheck:   Ptr(false),
+		RejectUnsignedCommits:      Ptr(false),
+		RejectNonDCOCommits:        Ptr(false),
+	}
+
+	rule, _, err := client.Projects.EditProjectPushRule(1, opt)
+	if err != nil {
+		t.Errorf("Projects.EditProjectPushRule returned error: %v", err)
+	}
+
+	want := &ProjectPushRules{
+		ID:                         1,
+		CommitMessageRegex:         "Fixes \\d+\\..*",
+		CommitMessageNegativeRegex: "ssh\\:\\/\\/",
+		BranchNameRegex:            "(feat|fix)\\/*",
+		DenyDeleteTag:              false,
+		MemberCheck:                false,
+		PreventSecrets:             false,
+		AuthorEmailRegex:           "@company.com$",
+		FileNameRegex:              "(jar|exe)$",
+		MaxFileSize:                5,
+		CommitCommitterCheck:       false,
+		CommitCommitterNameCheck:   false,
+		RejectUnsignedCommits:      false,
+		RejectNonDCOCommits:        false,
+	}
+
+	if !reflect.DeepEqual(want, rule) {
+		t.Errorf("Projects.EditProjectPushRule returned %+v, want %+v", rule, want)
+	}
+}
+
+func TestGetProjectWebhookHeader(t *testing.T) {
+	mux, client := setup(t)
+
+	// Removed most of the arguments to keep test slim
+	mux.HandleFunc("/api/v4/projects/1/hooks/1", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		fmt.Fprint(w, `{
+			"id": 1,
+			"custom_webhook_template": "{\"event\":\"{{object_kind}}\"}",
+			"custom_headers": [
+			  {
+				"key": "Authorization"
+			  },
+			  {
+				"key": "OtherKey"
+			  }
+			]
+		  }`)
+	})
+
+	hook, _, err := client.Projects.GetProjectHook(1, 1)
+	if err != nil {
+		t.Errorf("Projects.GetProjectHook returned error: %v", err)
+	}
+
+	want := &ProjectHook{
+		ID:                    1,
+		CustomWebhookTemplate: "{\"event\":\"{{object_kind}}\"}",
+		CustomHeaders: []*HookCustomHeader{
+			{
+				Key: "Authorization",
+			},
+			{
+				Key: "OtherKey",
+			},
+		},
+	}
+
+	if !reflect.DeepEqual(want, hook) {
+		t.Errorf("Projects.GetProjectHook returned %+v, want %+v", hook, want)
+	}
+}
+
+func TestSetProjectWebhookHeader(t *testing.T) {
+	mux, client := setup(t)
+	var bodyJson map[string]interface{}
+
+	// Removed most of the arguments to keep test slim
+	mux.HandleFunc("/api/v4/projects/1/hooks/1/custom_headers/Authorization", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodPut)
+		w.WriteHeader(http.StatusNoContent)
+
+		// validate that the `value` body is sent properly
+		body, err := io.ReadAll(r.Body)
+		if err != nil {
+			t.Fatalf("Unable to read body properly. Error: %v", err)
+		}
+
+		// Unmarshal the body into JSON so we can check it
+		_ = json.Unmarshal(body, &bodyJson)
+
+		fmt.Fprint(w, ``)
+	})
+
+	req, err := client.Projects.SetProjectCustomHeader(1, 1, "Authorization", &SetHookCustomHeaderOptions{Value: Ptr("testValue")})
+	if err != nil {
+		t.Errorf("Projects.SetProjectCustomHeader returned error: %v", err)
+	}
+
+	assert.Equal(t, bodyJson["value"], "testValue")
+	assert.Equal(t, http.StatusNoContent, req.StatusCode)
+}
+
+func TestDeleteProjectWebhookHeader(t *testing.T) {
+	mux, client := setup(t)
+
+	// Removed most of the arguments to keep test slim
+	mux.HandleFunc("/api/v4/projects/1/hooks/1/custom_headers/Authorization", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodDelete)
+		w.WriteHeader(http.StatusNoContent)
+		fmt.Fprint(w, ``)
+	})
+
+	req, err := client.Projects.DeleteProjectCustomHeader(1, 1, "Authorization")
+	if err != nil {
+		t.Errorf("Projects.DeleteProjectCustomHeader returned error: %v", err)
+	}
+
+	assert.Equal(t, http.StatusNoContent, req.StatusCode)
+}
