@@ -376,27 +376,36 @@ func TestDisableSlackApplication(t *testing.T) {
 func TestGetJiraService(t *testing.T) {
 	mux, client := setup(t)
 
-	mux.HandleFunc("/api/v4/projects/0/services/jira", func(w http.ResponseWriter, r *http.Request) {
-		testMethod(t, r, http.MethodGet)
-		fmt.Fprint(w, `{"id":1, "properties": {"jira_issue_transition_id": "2"}}`)
-	})
-
-	mux.HandleFunc("/api/v4/projects/1/services/jira", func(w http.ResponseWriter, r *http.Request) {
-		testMethod(t, r, http.MethodGet)
-		fmt.Fprint(w, `{"id":1, "properties": {"jira_issue_transition_id": 2}}`)
-	})
-
-	mux.HandleFunc("/api/v4/projects/2/services/jira", func(w http.ResponseWriter, r *http.Request) {
-		testMethod(t, r, http.MethodGet)
-		fmt.Fprint(w, `{"id":1, "properties": {"jira_issue_transition_id": "2,3"}}`)
-	})
-
-	mux.HandleFunc("/api/v4/projects/3/services/jira", func(w http.ResponseWriter, r *http.Request) {
+	mux.HandleFunc("/api/v4/projects/0/integrations/jira", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
 		fmt.Fprint(w, `{"id":1, "properties": {}}`)
 	})
 
+	mux.HandleFunc("/api/v4/projects/1/integrations/jira", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		fmt.Fprint(w, `{"id":1, "properties": {"jira_issue_transition_id": "2"}}`)
+	})
+
+	mux.HandleFunc("/api/v4/projects/2/integrations/jira", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		fmt.Fprint(w, `{"id":1, "properties": {"jira_issue_transition_id": 2}}`)
+	})
+
+	mux.HandleFunc("/api/v4/projects/3/integrations/jira", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		fmt.Fprint(w, `{"id":1, "properties": {"jira_issue_transition_id": "2,3"}}`)
+	})
+
+	mux.HandleFunc("/api/v4/projects/4/integrations/jira", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		fmt.Fprint(w, `{"id":1, "properties": {"jira_auth_type": 1}}`)
+	})
+
 	want := []*JiraService{
+		{
+			Service:    Service{ID: 1},
+			Properties: &JiraServiceProperties{},
+		},
 		{
 			Service: Service{ID: 1},
 			Properties: &JiraServiceProperties{
@@ -416,8 +425,10 @@ func TestGetJiraService(t *testing.T) {
 			},
 		},
 		{
-			Service:    Service{ID: 1},
-			Properties: &JiraServiceProperties{},
+			Service: Service{ID: 1},
+			Properties: &JiraServiceProperties{
+				JiraAuthType: 1,
+			},
 		},
 	}
 
@@ -436,21 +447,96 @@ func TestGetJiraService(t *testing.T) {
 func TestSetJiraService(t *testing.T) {
 	mux, client := setup(t)
 
-	mux.HandleFunc("/api/v4/projects/1/services/jira", func(w http.ResponseWriter, r *http.Request) {
+	mux.HandleFunc("/api/v4/projects/1/integrations/jira", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPut)
 	})
 
 	opt := &SetJiraServiceOptions{
-		URL:                   Ptr("asd"),
-		APIURL:                Ptr("asd"),
-		ProjectKey:            Ptr("as"),
-		Username:              Ptr("aas"),
-		Password:              Ptr("asd"),
-		Active:                Ptr(true),
-		JiraIssueTransitionID: Ptr("2,3"),
-		CommitEvents:          Ptr(true),
-		CommentOnEventEnabled: Ptr(true),
-		MergeRequestsEvents:   Ptr(true),
+		URL:                          Ptr("asd"),
+		APIURL:                       Ptr("asd"),
+		ProjectKey:                   Ptr("as"),
+		Username:                     Ptr("aas"),
+		Password:                     Ptr("asd"),
+		Active:                       Ptr(true),
+		JiraIssuePrefix:              Ptr("ASD"),
+		JiraIssueRegex:               Ptr("ASD"),
+		JiraIssueTransitionAutomatic: Ptr(true),
+		JiraIssueTransitionID:        Ptr("2,3"),
+		CommitEvents:                 Ptr(true),
+		MergeRequestsEvents:          Ptr(true),
+		CommentOnEventEnabled:        Ptr(true),
+		IssuesEnabled:                Ptr(true),
+		UseInheritedSettings:         Ptr(true),
+	}
+
+	_, err := client.Services.SetJiraService(1, opt)
+	if err != nil {
+		t.Fatalf("Services.SetJiraService returns an error: %v", err)
+	}
+}
+
+func TestSetJiraServiceProjecKeys(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/integrations/jira", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodPut)
+	})
+
+	opt := &SetJiraServiceOptions{
+		URL:                          Ptr("asd"),
+		APIURL:                       Ptr("asd"),
+		Username:                     Ptr("aas"),
+		Password:                     Ptr("asd"),
+		Active:                       Ptr(true),
+		JiraIssuePrefix:              Ptr("ASD"),
+		JiraIssueRegex:               Ptr("ASD"),
+		JiraIssueTransitionAutomatic: Ptr(true),
+		JiraIssueTransitionID:        Ptr("2,3"),
+		CommitEvents:                 Ptr(true),
+		MergeRequestsEvents:          Ptr(true),
+		CommentOnEventEnabled:        Ptr(true),
+		IssuesEnabled:                Ptr(true),
+		ProjectKeys:                  Ptr([]string{"as"}),
+		UseInheritedSettings:         Ptr(true),
+	}
+
+	_, err := client.Services.SetJiraService(1, opt)
+	if err != nil {
+		t.Fatalf("Services.SetJiraService returns an error: %v", err)
+	}
+}
+
+func TestSetJiraServiceAuthTypeBasicAuth(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/integrations/jira", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodPut)
+	})
+
+	opt := &SetJiraServiceOptions{
+		URL:          Ptr("asd"),
+		Username:     Ptr("aas"),
+		Password:     Ptr("asd"),
+		JiraAuthType: Ptr(0),
+	}
+
+	_, err := client.Services.SetJiraService(1, opt)
+	if err != nil {
+		t.Fatalf("Services.SetJiraService returns an error: %v", err)
+	}
+}
+
+func TestSetJiraServiceAuthTypeTokenAuth(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/integrations/jira", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodPut)
+	})
+
+	opt := &SetJiraServiceOptions{
+		URL:          Ptr("asd"),
+		Password:     Ptr("asd"),
+		JiraAuthType: Ptr(1),
 	}
 
 	_, err := client.Services.SetJiraService(1, opt)
@@ -462,7 +548,7 @@ func TestSetJiraService(t *testing.T) {
 func TestDeleteJiraService(t *testing.T) {
 	mux, client := setup(t)
 
-	mux.HandleFunc("/api/v4/projects/1/services/jira", func(w http.ResponseWriter, r *http.Request) {
+	mux.HandleFunc("/api/v4/projects/1/integrations/jira", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodDelete)
 	})
 
@@ -670,6 +756,52 @@ func TestDeletePrometheusService(t *testing.T) {
 	}
 }
 
+func TestGetRedmineService(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/integrations/redmine", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		fmt.Fprint(w, `{"id":1}`)
+	})
+	want := &RedmineService{Service: Service{ID: 1}}
+
+	service, _, err := client.Services.GetRedmineService(1)
+	if err != nil {
+		t.Fatalf("Services.GetRedmineService returns an error: %v", err)
+	}
+	if !reflect.DeepEqual(want, service) {
+		t.Errorf("Services.GetRedmineService returned %+v, want %+v", service, want)
+	}
+}
+
+func TestSetRedmineService(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/integrations/redmine", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodPut)
+	})
+
+	opt := &SetRedmineServiceOptions{Ptr("t"), Ptr("u"), Ptr("a"), Ptr(false)}
+
+	_, err := client.Services.SetRedmineService(1, opt)
+	if err != nil {
+		t.Fatalf("Services.SetRedmineService returns an error: %v", err)
+	}
+}
+
+func TestDeleteRedmineService(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/integrations/redmine", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodDelete)
+	})
+
+	_, err := client.Services.DeleteRedmineService(1)
+	if err != nil {
+		t.Fatalf("Services.DeleteRedmineService returns an error: %v", err)
+	}
+}
+
 func TestGetSlackService(t *testing.T) {
 	mux, client := setup(t)
 
