@@ -17,16 +17,18 @@
 package gitlab
 
 import (
+	"bytes"
 	"encoding/json"
 	"errors"
 	"fmt"
 	"net/url"
 	"reflect"
 	"strconv"
+	"strings"
 	"time"
 )
 
-// Ptr is a helper returns a pointer to v.
+// Ptr is a helper that returns a pointer to v.
 func Ptr[T any](v T) *T {
 	return &v
 }
@@ -60,7 +62,7 @@ func AccessControl(v AccessControlValue) *AccessControlValue {
 // GitLab API docs: https://docs.gitlab.com/ee/user/permissions.html
 type AccessLevelValue int
 
-// List of available access levels
+// List of available access levels.
 //
 // GitLab API docs: https://docs.gitlab.com/ee/user/permissions.html
 const (
@@ -87,6 +89,11 @@ func AccessLevel(v AccessLevelValue) *AccessLevelValue {
 	return Ptr(v)
 }
 
+type AccessLevelDetails struct {
+	IntegerValue AccessLevelValue `json:"integer_value"`
+	StringValue  string           `json:"string_value"`
+}
+
 // UserIDValue represents a user ID value within GitLab.
 type UserIDValue string
 
@@ -111,7 +118,7 @@ func ApproverIDs(v interface{}) *ApproverIDsValue {
 	}
 }
 
-// EncodeValues implements the query.Encoder interface
+// EncodeValues implements the query.Encoder interface.
 func (a *ApproverIDsValue) EncodeValues(key string, v *url.Values) error {
 	switch value := a.value.(type) {
 	case UserIDValue:
@@ -126,12 +133,12 @@ func (a *ApproverIDsValue) EncodeValues(key string, v *url.Values) error {
 	return nil
 }
 
-// MarshalJSON implements the json.Marshaler interface
+// MarshalJSON implements the json.Marshaler interface.
 func (a ApproverIDsValue) MarshalJSON() ([]byte, error) {
 	return json.Marshal(a.value)
 }
 
-// UnmarshalJSON implements the json.Unmarshaler interface
+// UnmarshalJSON implements the json.Unmarshaler interface.
 func (a *ApproverIDsValue) UnmarshalJSON(bytes []byte) error {
 	return json.Unmarshal(bytes, a.value)
 }
@@ -151,7 +158,7 @@ func AssigneeID(v interface{}) *AssigneeIDValue {
 	}
 }
 
-// EncodeValues implements the query.Encoder interface
+// EncodeValues implements the query.Encoder interface.
 func (a *AssigneeIDValue) EncodeValues(key string, v *url.Values) error {
 	switch value := a.value.(type) {
 	case UserIDValue:
@@ -162,12 +169,12 @@ func (a *AssigneeIDValue) EncodeValues(key string, v *url.Values) error {
 	return nil
 }
 
-// MarshalJSON implements the json.Marshaler interface
+// MarshalJSON implements the json.Marshaler interface.
 func (a AssigneeIDValue) MarshalJSON() ([]byte, error) {
 	return json.Marshal(a.value)
 }
 
-// UnmarshalJSON implements the json.Unmarshaler interface
+// UnmarshalJSON implements the json.Unmarshaler interface.
 func (a *AssigneeIDValue) UnmarshalJSON(bytes []byte) error {
 	return json.Unmarshal(bytes, a.value)
 }
@@ -187,7 +194,7 @@ func ReviewerID(v interface{}) *ReviewerIDValue {
 	}
 }
 
-// EncodeValues implements the query.Encoder interface
+// EncodeValues implements the query.Encoder interface.
 func (a *ReviewerIDValue) EncodeValues(key string, v *url.Values) error {
 	switch value := a.value.(type) {
 	case UserIDValue:
@@ -198,12 +205,12 @@ func (a *ReviewerIDValue) EncodeValues(key string, v *url.Values) error {
 	return nil
 }
 
-// MarshalJSON implements the json.Marshaler interface
+// MarshalJSON implements the json.Marshaler interface.
 func (a ReviewerIDValue) MarshalJSON() ([]byte, error) {
 	return json.Marshal(a.value)
 }
 
-// UnmarshalJSON implements the json.Unmarshaler interface
+// UnmarshalJSON implements the json.Unmarshaler interface.
 func (a *ReviewerIDValue) UnmarshalJSON(bytes []byte) error {
 	return json.Unmarshal(bytes, a.value)
 }
@@ -254,6 +261,42 @@ func BuildState(v BuildStateValue) *BuildStateValue {
 	return Ptr(v)
 }
 
+// CommentEventAction identifies if a comment has been newly created or updated.
+//
+// GitLab API docs:
+// https://docs.gitlab.com/ee/user/project/integrations/webhook_events.html#comment-events
+type CommentEventAction string
+
+const (
+	CommentEventActionCreate CommentEventAction = "create"
+	CommentEventActionUpdate CommentEventAction = "update"
+)
+
+// ContainerRegistryStatus represents the status of a Container Registry.
+//
+// GitLab API docs:
+// https://docs.gitlab.com/ee/api/container_registry.html#list-registry-repositories
+type ContainerRegistryStatus string
+
+// ContainerRegistryStatus represents all valid statuses of a Container Registry.
+//
+// Undocumented, see code at:
+// https://gitlab.com/gitlab-org/gitlab/-/blob/master/app/models/container_repository.rb?ref_type=heads#L35
+const (
+	ContainerRegistryStatusDeleteScheduled ContainerRegistryStatus = "delete_scheduled"
+	ContainerRegistryStatusDeleteFailed    ContainerRegistryStatus = "delete_failed"
+	ContainerRegistryStatusDeleteOngoing   ContainerRegistryStatus = "delete_ongoing"
+)
+
+// DeploymentApprovalStatus represents a Gitlab deployment approval status.
+type DeploymentApprovalStatus string
+
+// These constants represent all valid deployment approval statuses.
+const (
+	DeploymentApprovalStatusApproved DeploymentApprovalStatus = "approved"
+	DeploymentApprovalStatusRejected DeploymentApprovalStatus = "rejected"
+)
+
 // DeploymentStatusValue represents a Gitlab deployment status.
 type DeploymentStatusValue string
 
@@ -274,12 +317,43 @@ func DeploymentStatus(v DeploymentStatusValue) *DeploymentStatusValue {
 	return Ptr(v)
 }
 
-// EventTypeValue represents actions type for contribution events
+// DORAMetricType represents all valid DORA metrics types.
+//
+// GitLab API docs: https://docs.gitlab.com/ee/api/dora/metrics.html
+type DORAMetricType string
+
+// List of available DORA metric type names.
+//
+// GitLab API docs: https://docs.gitlab.com/ee/api/dora/metrics.html
+const (
+	DORAMetricDeploymentFrequency  DORAMetricType = "deployment_frequency"
+	DORAMetricLeadTimeForChanges   DORAMetricType = "lead_time_for_changes"
+	DORAMetricTimeToRestoreService DORAMetricType = "time_to_restore_service"
+	DORAMetricChangeFailureRate    DORAMetricType = "change_failure_rate"
+)
+
+// DORAMetricInterval represents the time period over which the
+// metrics are aggregated.
+//
+// GitLab API docs: https://docs.gitlab.com/ee/api/dora/metrics.html
+type DORAMetricInterval string
+
+// List of available DORA metric interval types.
+//
+// GitLab API docs: https://docs.gitlab.com/ee/api/dora/metrics.html
+const (
+	DORAMetricIntervalDaily   DORAMetricInterval = "daily"
+	DORAMetricIntervalMonthly DORAMetricInterval = "monthly"
+	DORAMetricIntervalAll     DORAMetricInterval = "all"
+)
+
+// EventTypeValue represents actions type for contribution events.
 type EventTypeValue string
 
-// List of available action type
+// List of available action type.
 //
-// GitLab API docs: https://docs.gitlab.com/ee/user/profile/contributions_calendar.html#user-contribution-events
+// GitLab API docs:
+// https://docs.gitlab.com/ee/user/profile/contributions_calendar.html#user-contribution-events
 const (
 	CreatedEventType   EventTypeValue = "created"
 	UpdatedEventType   EventTypeValue = "updated"
@@ -294,10 +368,10 @@ const (
 	ExpiredEventType   EventTypeValue = "expired"
 )
 
-// EventTargetTypeValue represents actions type value for contribution events
+// EventTargetTypeValue represents actions type value for contribution events.
 type EventTargetTypeValue string
 
-// List of available action type
+// List of available action type.
 //
 // GitLab API docs: https://docs.gitlab.com/ee/api/events.html#target-types
 const (
@@ -312,7 +386,8 @@ const (
 
 // FileActionValue represents the available actions that can be performed on a file.
 //
-// GitLab API docs: https://docs.gitlab.com/ee/api/commits.html#create-a-commit-with-multiple-files-and-actions
+// GitLab API docs:
+// https://docs.gitlab.com/ee/api/commits.html#create-a-commit-with-multiple-files-and-actions
 type FileActionValue string
 
 // The available file actions.
@@ -368,7 +443,7 @@ func GenericPackageStatus(v GenericPackageStatusValue) *GenericPackageStatusValu
 // ISOTime represents an ISO 8601 formatted date.
 type ISOTime time.Time
 
-// ISO 8601 date format
+// ISO 8601 date format.
 const iso8601 = "2006-01-02"
 
 // ParseISOTime parses an ISO 8601 formatted date.
@@ -423,6 +498,35 @@ func (t ISOTime) String() string {
 	return time.Time(t).Format(iso8601)
 }
 
+// Labels represents a list of labels.
+type Labels []string
+
+// LabelOptions is a custom type with specific marshaling characteristics.
+type LabelOptions []string
+
+// MarshalJSON implements the json.Marshaler interface.
+func (l *LabelOptions) MarshalJSON() ([]byte, error) {
+	if *l == nil {
+		return []byte(`null`), nil
+	}
+	return json.Marshal(strings.Join(*l, ","))
+}
+
+// UnmarshalJSON implements the json.Unmarshaler interface.
+func (l *LabelOptions) UnmarshalJSON(data []byte) error {
+	type alias LabelOptions
+	if !bytes.HasPrefix(data, []byte("[")) {
+		data = []byte(fmt.Sprintf("[%s]", string(data)))
+	}
+	return json.Unmarshal(data, (*alias)(l))
+}
+
+// EncodeValues implements the query.EncodeValues interface.
+func (l *LabelOptions) EncodeValues(key string, v *url.Values) error {
+	v.Set(key, strings.Join(*l, ","))
+	return nil
+}
+
 // LinkTypeValue represents a release link type.
 type LinkTypeValue string
 
@@ -598,6 +702,46 @@ func ProjectCreationLevel(v ProjectCreationLevelValue) *ProjectCreationLevelValu
 	return Ptr(v)
 }
 
+// ProjectHookEvent represents a project hook event.
+//
+// GitLab API docs: https://docs.gitlab.com/ee/api/projects.html#hook-events
+type ProjectHookEvent string
+
+// List of available project hook events.
+//
+// GitLab API docs: https://docs.gitlab.com/ee/api/projects.html#hook-events
+const (
+	ProjectHookEventPush                ProjectHookEvent = "push_events"
+	ProjectHookEventTagPush             ProjectHookEvent = "tag_push_events"
+	ProjectHookEventIssues              ProjectHookEvent = "issues_events"
+	ProjectHookEventConfidentialIssues  ProjectHookEvent = "confidential_issues_events"
+	ProjectHookEventNote                ProjectHookEvent = "note_events"
+	ProjectHookEventMergeRequests       ProjectHookEvent = "merge_requests_events"
+	ProjectHookEventJob                 ProjectHookEvent = "job_events"
+	ProjectHookEventPipeline            ProjectHookEvent = "pipeline_events"
+	ProjectHookEventWiki                ProjectHookEvent = "wiki_page_events"
+	ProjectHookEventReleases            ProjectHookEvent = "releases_events"
+	ProjectHookEventEmoji               ProjectHookEvent = "emoji_events"
+	ProjectHookEventResourceAccessToken ProjectHookEvent = "resource_access_token_events"
+)
+
+// ResourceGroupProcessMode represents a process mode for a resource group
+// within a GitLab project.
+//
+// GitLab API docs:
+// https://docs.gitlab.com/ee/ci/resource_groups/index.html#process-modes
+type ResourceGroupProcessMode string
+
+// List of available resource group process modes.
+//
+// GitLab API docs:
+// https://docs.gitlab.com/ee/ci/resource_groups/index.html#process-modes
+const (
+	Unordered   ResourceGroupProcessMode = "unordered"
+	OldestFirst ResourceGroupProcessMode = "oldest_first"
+	NewestFirst ResourceGroupProcessMode = "newest_first"
+)
+
 // SharedRunnersSettingValue determines whether shared runners are enabled for a
 // group’s subgroups and projects.
 //
@@ -614,7 +758,8 @@ const (
 	DisabledAndOverridableSharedRunnersSettingValue   SharedRunnersSettingValue = "disabled_and_overridable"
 	DisabledAndUnoverridableSharedRunnersSettingValue SharedRunnersSettingValue = "disabled_and_unoverridable"
 
-	// Deprecated: DisabledWithOverrideSharedRunnersSettingValue is deprecated in favor of DisabledAndOverridableSharedRunnersSettingValue
+	// Deprecated: DisabledWithOverrideSharedRunnersSettingValue is deprecated
+	// in favor of DisabledAndOverridableSharedRunnersSettingValue.
 	DisabledWithOverrideSharedRunnersSettingValue SharedRunnersSettingValue = "disabled_with_override"
 )
 
